<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<script type="text/javascript">
    en4.core.runonce.add(function() {
        // Enable links
        scriptJquery('.grid_listing_item_desc').enableLinks();
    });
</script>
<?php if( $this->paginator->getTotalItemCount() > 0 ): ?>
	<div class='container no-padding bizlists_listing'>
		<div class='grid_listing'>
			<?php foreach( $this->paginator as $item ): ?>
				<div class='grid_listing_item'>
					<article>
						<div class='grid_listing_item_thumb'> 
							<?php echo $this->htmlLink($item->getHref(), $this->itemBackgroundPhoto($item, 'thumb.normal')) ?>
						</div>
						<div class='grid_listing_item_info'>
							<div class='grid_listing_item_title'>
								<?php echo $this->htmlLink($item->getHref(), $item->getTitle()) ?>
								<?php if( $item->closed ): ?>
									<i class="icon_closed" data-bs-toggle="tooltip" title="<?php echo $this->translate("Closed")?>"></i>
								<?php endif;?>
							</div>
							<div class='grid_listing_item_owner'>
								<span><?php echo $this->translate('by');?> <?php echo $this->htmlLink($item->getOwner()->getHref(), $item->getOwner()->getTitle()) ?></span>
								<span><?php echo $this->timestamp(strtotime($item->creation_date)) ?></span>
							</div>
							<div class='grid_listing_item_desc'> <?php echo $this->string()->truncate($this->string()->stripTags($item->body), 120) ?> </div>
							
							<!-- <div class='bizlists_browse_info_blurb'>
							<?php // $fieldStructure = Engine_Api::_()->fields()->getFieldsStructurePartial($item)?>
							<?php //echo $this->fieldValueLoop($item, $fieldStructure) ?> </div> -->
						</div>
					</article>
				</div>
			<?php endforeach; ?>
		</div>
	</div>
<?php else:?>
   <div class="no_result_tip">
      <i><img src="application/modules/Core/externals/images/no-results.png" height="100" width="100" alt="<?php echo $this->translate("No Result")?>"></i>
      <p> <?php echo $this->translate('No one has posted a business listing yet.');?> </p>
   </div>
<?php endif; ?>
<?php echo $this->paginationControl($this->paginator, null, null, array('pageAsQuery' => true,'query' => $this->formValues)); ?> 
