<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Bizlist_Bootstrap extends Engine_Application_Bootstrap_Abstract
{
    public function __construct($application) {
        parent::__construct($application);
        $front = Zend_Controller_Front::getInstance();
        $front->registerPlugin(new Bizlist_Plugin_Core);
    }
}