<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/

class Bizlist_Widget_BreadcrumbController extends Engine_Content_Widget_Abstract {

  public function indexAction() {
  
    $this->view->bizlist = $bizlist = Engine_Api::_()->core()->getSubject('bizlist');
    if(!$bizlist)
      return $this->setNoRender();
  }
}
