
/* ICONS */
.icon_bizlist_new:before{
  content:"\f067" !important;
}
.activity_icon_comment_bizlist:before{
  content:"\f075";
  font-family:'Font Awesome 6 Free';
}
.item_icon_bizlist:before{
  content:"\e2ea";
	font-family:uicons-regular-rounded !important;
	font-weight:400 !important;
}
.bg_item_nophoto.bg_item_photo_bizlist:before{
  content:"\f1ad";
}
.bg_thumb_profile.bg_item_photo_bizlist.bg_item_nophoto:before{
  font-size: 15ch;
}

/*VIEW BIZLIST*/
.bizlist_top{
  display:flex;
}
.bizlist_top > .bizlist_left{
  width:45%;
  display:flex;
  padding-right:20px;
}
[dir="rtl"] .bizlist_top > .bizlist_left{
  padding-right:0;
  padding-left: 20px;
}
.bizlist_top > .bizlist_left .bizlists_thumbs_nav{
  width:80px;
  min-width:80px;
  margin-right:20px;
}
[dir="rtl"] .bizlist_top > .bizlist_left .bizlists_thumbs_nav{
  margin-right:0;
  margin-left:20px;
}
.bizlist_top > .bizlist_left .bizlists_thumbs_nav .slick-slide > div{
  height:80px !important;
  margin-bottom:10px;
}
.bizlist_top > .bizlist_left .bizlists_thumbs_nav img{
  border-width:1px;
  cursor: pointer;
  width:98%;
  height:80px;
  object-fit:cover;
}
.bizlist_top > .bizlist_left .bizlists_thumbs_main_image{
  flex:1;
  max-width:80%;
}
.bizlist_top > .bizlist_left .bizlists_thumbs_main img{
  width:100%;
  height:100%;
  object-fit:cover;
  object-position:center center;
}
.bizlists_thumbs_description{
  padding:10px 0;
  word-break:break-word;
}
.bizlists_thumbs_main{
  border-width:1px;
  height:350px;
  overflow:hidden;
}
.bizlists_thumbs_nav .slick-arrow{
  font-size:0;
  background:none !important;
  border:0 !important;
  opacity:1 !important;
}
.bizlists_thumbs_nav .slick-disabled{
  display:none !important;
}
.bizlists_thumbs_nav .slick-slide{
  outline:0;
  border:0 !important;
}
.bizlists_thumbs_nav .slick-arrow:before{
  background:var(--theme-list-background-color);
  border:1px solid var(--theme-border-color);
  color:var(--theme-font-color);
  position:absolute;
  display:block;
  font-family:'Font Awesome 6 Free';
  font-size:16px;
  width:30px;
  height:30px;
  line-height:30px;
  margin:auto;
  left:0;
  right:0;
  top:5px;
  font-weight:600;
  z-index:9;
}
.bizlists_thumbs_nav .slick-prev:before{
  content:"\f077";
}
.bizlists_thumbs_nav .slick-next:before{
  content:"\f078";
  top:auto;
  bottom:25px;
}
.bizlist_top > .bizlist_right{
  width:55%;
}
.bizlist_right > h1{
  border-bottom-width:1px;
  padding-bottom:0.625rem;
  margin-bottom:0.625rem;
}
.bizlist_right .bizlist_entrylist_entry_date{
  color:var(--theme-font-color-light);
  font-size:var(--theme-font-size-small);
  margin-bottom:0.625rem;
}
.bizlist_right .rating {
  margin-bottom:0.625rem;
}
.bizlist_right > h3{
  padding:0;
  margin:1.25rem 0 0.625rem;
  font-weight:500;
}
.bizlist_entrylist_entry_body{
  margin:1.875rem 0 0.625rem;
}
.bizlists_entrylist .profile_fields > ul{
  padding:10px 0;
}
.bizlists_entrylist .profile_fields > ul > li > span:nth-child(1){
  display:inline-flex;
}
.bizlists_entrylist .profile_fields > ul > li > span > i{
  margin-top: 3px;
  margin-right: 5px;
  text-align: center;
}
[dir="rtl"] .bizlists_entrylist .profile_fields > ul > li > span > i{
  margin-right: 0px;
  margin-left: 5px;
}
.bizlists_entrylist .profile_fields > ul > li > span:last-child{
  background:none;
  width:auto;
}
.bizlists_entrylist .profile_fields > ul > li > span:last-child ul,
.bizlists_entrylist .profile_fields > ul > li > span:last-child ol {
  padding-left:20px;
}
.bizlists_entrylist .profile_fields > ul > li > span:last-child ul{
  list-style-type:disc;
}
.bizlists_entrylist .profile_fields > ul > li > span:last-child br,
.bizlist_right br {
  display: none;
}
.bizlist_entrylist_entry_body h4{
  font-weight:600;
  border-bottom-width:1px;
  padding-bottom:10px;
  margin-bottom:10px;
}
.bizlist_entrylist_entry_body p{
  line-height:1.5em;
  font-weight: 400;
}
.bizlist_entrylist_entry_body .bizlists_tags > a{
  border-radius:5px;
  display:inline-block;
  margin:10px 4px 0 0;
  padding:2px 10px;
  float:none !important;
}
.bizlists_entrylist_options{
  border-top-width:1px;
  border-top-style:dashed;
  padding-top:10px;
}
.bizlists_entrylist_options > a{
  color:var(--theme-font-color);
  font-weight:var(--theme-font-weight-bold);
}
.layout_page_bizlist_index_view .layout_core_comments h3{
  display:none;
}
/*EDIT BIZLIST LISTING*/

/* RESPONSIVE */
@media(min-width:768px) and (max-width:900px){
  .bizlist_top > .bizlist_left .bizlists_thumbs_main{
    height:300px;
  }
  .bizlists_thumbs_nav .slick-next:before{
    bottom:auto;
    margin-top:-40px;
  }
}
@media(min-width:768px){
  .bizlist_top > .bizlist_left .bizlists_thumbs_nav{
    max-height:400px;
  }
}
@media(max-width:767px){
  .bizlists_thumbs_main{
    display:none;
  }
  .bizlist_top > .bizlist_left,
  .bizlist_top > .bizlist_right,
  .bizlist_top{
    width:100%;
    display:block;
    padding:0;
  }
  .bizlist_top > .bizlist_left .bizlists_thumbs_nav{
    width:100%;
    margin-bottom:15px;
    margin-right:0;
  }
  .bizlists_thumbs_nav .slick-slide{
    height:200px;
  }
  .bizlist_top > .bizlist_left .bizlists_thumbs_nav img{
    width:100%;
    height:200px;
    border:0;
    border-radius:8px;
  }
  .bizlists_thumbs_nav .slick-slide > div{
    height:200px !important;
    margin:0;
  }
  .bizlists_thumbs_nav .slick-dots > li{
    display:inline-block;
    margin:0 3px;
  }
  .bizlists_thumbs_nav .slick-dots{
    text-align:center;
  }
  .bizlists_thumbs_nav .slick-dots li button{
    width:8px;
    font-size:0;
    height:8px;
    border-radius:20px;
    background:var(--theme-font-color) !important;
    opacity:.2;
    border:0 !important;
  }
  .bizlists_thumbs_nav .slick-dots li.slick-active button{
    opacity:1;
  }
  .bizlist_right > h3{
    display:none;
  }
  .bizlist_entrylist_entry_body {
    margin: 5px;
  }
  .bizlists_entrylist .profile_fields{
    margin-top: 0;
  }
  .bizlists_entrylist_options {
    margin-top: 30px;
  }
  .bizlists_thumbs_description{
    padding: 0;
  }
  .bizlists_entrylist .profile_fields > ul > li > span{
    float: none;
    margin-right: 0;
    margin-bottom: 5px;
    display:block !important;
    width: auto;
  }
}
