<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<div class='layout_middle'>
  <div class='generic_layout_container'>
    <div class='global_form_wrap'>
      <form method="post" class="global_form">
        <div>
          <div>
          <h3><?php echo $this->translate('Listing Posted');?></h3>
          <p>
            <?php echo $this->translate('Your listing was successfully published. Would you like to add some photos to it?');?>
          </p>
          <p>
            <input type="hidden" name="confirm" value="true"/>
            <a class='btn btn-primary' href="businesses/photo/upload/subject/<?php echo $this->bizlist->getGuid() ; ?>"><?php echo $this->translate('Add Photos');?></a>
            <?php echo $this->translate('or');?>
            <a href='<?php echo $this->url(array('action' => 'manage'), 'bizlist_general', true) ?>'>
              <?php echo $this->translate('continue to my listing');?>
            </a>
          </p>
        </div>
        </div>
      </form>
    </div>
  </div>
</div>
