<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<ul class="sidebar_list bizlists_sidebar_list">
  <?php foreach( $this->paginator as $item ): ?>
    <li class="sidebar_list_item">
      <div class="sidebar_list_item_thumb">
        <?php echo $this->htmlLink($item->getHref(), $this->itemBackgroundPhoto($item,'thumb.icon')) ?>
      </div>
      <div class="sidebar_list_item_info">
        <div class="sidebar_list_item_title">
          <?php echo $this->htmlLink($item->getHref(), $item->getTitle()) ?>
          <?php if( $item->closed ): ?>
            <i class="icon_closed" data-bs-toggle="tooltip" title="<?php echo $this->translate("Closed")?>"></i>
          <?php endif ?>
        </div>
        <div class="sidebar_list_item_owner">
          <?php echo $this->timestamp(strtotime($item->creation_date)) ?>
        </div>
      </div>
    </li>
  <?php endforeach; ?>
  <?php if( $this->paginator->getPages()->pageCount > 1 ): ?>
    <li class="sidebar_list_item_more"><?php echo $this->partial('_widgetLinks.tpl', 'core', array('url' => $this->url(array('action' => 'index'), 'bizlist_general', true), 'param' => array('orderby' => 'view_count'))); ?></li>
  <?php endif; ?>
</ul>