<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Bizlist_Model_DbTable_Albums extends Engine_Db_Table
{
  protected $_rowClass = 'Bizlist_Model_Album';
}
