<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Bizlist_Form_Edit extends Bizlist_Form_Create
{
    public $_error = array();
    protected $_item;

    public function getItem()
    {
        return $this->_item;
    }

    public function setItem(Core_Model_Item_Abstract $item)
    {
        $this->_item = $item;
        return $this;
    }

    public function init()
    {
        parent::init();


        $this->setTitle('Edit Business Listing')
            ->setDescription('Edit your listing below, then click \"Save Changes\" to save your listing.');
        $this->addElement('Radio', 'cover', array(
            'label' => 'Album Cover',
        ));
        $this->execute->setLabel('Save Changes');
    }
}
