UPDATE `engine4_activity_actiontypes` SET `commentable` = '4' WHERE `engine4_activity_actiontypes`.`type` = 'comment_bizlist';

UPDATE `engine4_activity_actiontypes` SET `commentable` = '4' WHERE `engine4_activity_actiontypes`.`type` = 'like_bizlist';