INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES
('core_main_quickcreate_bizlist', 'bizlist', 'Post a New Listing', 'Bizlist_Plugin_Menus::canCreateBizlists', '{"route":"bizlist_general","action":"create","class":"buttonlink icon_bizlist_new","icon":"fi fi-rr-business-time"}', 'core_main_quickcreate', '', 3);

UPDATE `engine4_core_menuitems` SET `params` = '{"route":"bizlist_general","icon":"fi fi-rr-business-time"}' WHERE `engine4_core_menuitems`.`name` = 'core_main_bizlist';

UPDATE `engine4_core_menuitems` SET `description` = 'List your business, attract customers and grow revenue' WHERE `engine4_core_menuitems`.`name` = 'core_main_bizlist';